##  Overview
The main idea behind the Interface Fact Sheet is to take a business perspective. Typical questions raised are:
  * How are Data Objects exchanged?
  * How are Applications related?
  * What needs to be considered within a Project?


Customers also use it for more technical use cases (e.g. which Web Services are offered), but often the business use cases are more prominent.
